SliderWidget<T> class

SeedKit - Виджет слайдера

Inheritance
Available extensions

Constructors

SliderWidget({Key? key, required List<T> elements, required WidgetItemBuilder<T> itemBuilder, PageController? controller, double aspectRatio = 16 / 9, Duration? flippingPeriod, Widget indicatorBuilder(int currentPage, int maxPage)?, Alignment indicatoAlignment = .bottomCenter, BorderRadius borderRadius = const BorderRadius.all(Radius.zero)})
const

Properties

aspectRatio double
final
borderRadius BorderRadius
final
controller PageController?
final
elements List<T>
final
flippingPeriod Duration?
final
hashCode int
The hash code for this object.
no setterinherited
indicatoAlignment Alignment
final
indicatorBuilder Widget Function(int currentPage, int maxPage)?
final
itemBuilder WidgetItemBuilder<T>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

animate({Key? key, List<Effect>? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, AnimationController? controller, Adapter? adapter, double? target, double? value}) Animate

Available on Widget, provided by the AnimateWidgetExtensions extension

Wraps the target Widget in an Animate instance, and returns the instance for chaining calls. Ex. myWidget.animate() is equivalent to Animate(child: myWidget).
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<SliderWidget<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited