SliversWidget class

SeedKit - Виджет ленивого Sliver списка

slivers: []

Inheritance
Available extensions

Constructors

SliversWidget({Key? key, required List<Widget> slivers, Axis scrollDirection = .vertical, ScrollController? scrollController, ScrollPhysics? physics = const AlwaysScrollableScrollPhysics(), double scrollPadding = 0, double navigationBarHeight = 0, bool withoutBottomPadding = false, void onRefresh()?, bool shrinkWrap = false, bool isReverse = false, UISliversThemeData? theme})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isReverse bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
Высота нижней навигационной панели если она есть
final
onRefresh → void Function()?
final
physics ScrollPhysics?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollController ScrollController?
final
scrollDirection Axis
final
scrollPadding double
Отступ для скролла.
final
shrinkWrap bool
final
slivers List<Widget>
final
theme UISliversThemeData?
finalinherited
withoutBottomPadding bool
Отключить любые отступы снизу
final

Methods

animate({Key? key, List<Effect>? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, AnimationController? controller, Adapter? adapter, double? target, double? value}) Animate

Available on Widget, provided by the AnimateWidgetExtensions extension

Wraps the target Widget in an Animate instance, and returns the instance for chaining calls. Ex. myWidget.animate() is equivalent to Animate(child: myWidget).
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
builder(BuildContext context, UISliversThemeData theme) Widget
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited