SnackbarButtonModel class

Constructors

SnackbarButtonModel({required dynamic onTap(), String? text, UIButtonThemeData theme = const UIButtonThemeData()})

Properties

hashCode int
The hash code for this object.
no setterinherited
onTap → dynamic Function()
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
final
theme UIButtonThemeData
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited