TextFieldWidget class

SeedKit - Базовый виджет текстового поля

Inheritance
Available extensions

Constructors

TextFieldWidget({Key? key, TextEditingController? controller, String? titleText, TextInputType keyboardType = TextInputType.text, dynamic onChanged(String value)?, dynamic onSymbolErased()?, dynamic onSaved(String value)?, dynamic onFocusChanged(bool isFocused)?, String? hintText, Widget? suffixWidget, Widget? prefixWidget, int? maxLength, TextInputAction? textInputAction, TextCapitalization textCapitalization = TextCapitalization.sentences, List<TextInputFormatter>? inputFormatters, bool autofocus = false, int? maxLines = 1, bool autocorrect = true, bool isRequired = false, bool withClearSuffix = false, bool withObscureText = false, bool enabled = true, FocusNode? focusNode, dynamic onTap(BuildContext context)?, dynamic onEditingComplete()?, String? onValid(String value)?, String? onCustomValid(String value)?, dynamic onCleared()?, EdgeInsets margin = .zero, Widget contextMenuBuilder(BuildContext, EditableTextState)?, UITextFieldThemeData? theme})
const

Properties

autocorrect bool
final
autofocus bool
final
contextMenuBuilder Widget Function(BuildContext, EditableTextState)?
final
controller TextEditingController?
final
enabled bool
final
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
hintText String?
final
inputFormatters List<TextInputFormatter>?
final
isRequired bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType TextInputType
final
margin EdgeInsets
final
maxLength int?
final
maxLines int?
final
onChanged → dynamic Function(String value)?
final
onCleared → dynamic Function()?
final
onCustomValid String? Function(String value)?
final
onEditingComplete → dynamic Function()?
final
onFocusChanged → dynamic Function(bool isFocused)?
final
onSaved → dynamic Function(String value)?
final
onSymbolErased → dynamic Function()?
final
onTap → dynamic Function(BuildContext context)?
final
onValid String? Function(String value)?
final
prefixWidget Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suffixWidget Widget?
final
textCapitalization TextCapitalization
final
textInputAction TextInputAction?
final
theme UITextFieldThemeData?
finalinherited
titleText String?
final
withClearSuffix bool
final
withObscureText bool
final

Methods

animate({Key? key, List<Effect>? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, AnimationController? controller, Adapter? adapter, double? target, double? value}) Animate

Available on Widget, provided by the AnimateWidgetExtensions extension

Wraps the target Widget in an Animate instance, and returns the instance for chaining calls. Ex. myWidget.animate() is equivalent to Animate(child: myWidget).
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<TextFieldWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited