UIBadgeThemeData class

Inheritance
Implemented types

Constructors

UIBadgeThemeData({Color? color, TextStyle? textStyle})
const
UIBadgeThemeData.config({Color? color = Colors.red, TextStyle? textStyle = const TextStyle(fontSize: 12)})
const

Properties

color Color?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle TextStyle?
final
type Object
The extension's type.
no setterinherited

Methods

copyWith() ThemeExtension<UIBadgeThemeData>
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<UIBadgeThemeData>? other, double t) ThemeExtension<UIBadgeThemeData>
Linearly interpolate with another ThemeExtension object.
override
merge(covariant UIBadgeThemeData? other) UIBadgeThemeData
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited