UICheckBoxThemeData class

Inheritance
Implemented types

Constructors

UICheckBoxThemeData({double? size, double? radius, EdgeInsets? padding, Color? activeColor, Color? disabledColor, Color? borderColor, Color? iconColor, SvgGenImage? selectedIcon})
const
UICheckBoxThemeData.config({double? size = 48, double? radius = 4, EdgeInsets? padding = const EdgeInsets.all(2), Color? activeColor = Colors.blue, Color? disabledColor = Colors.white70, Color? borderColor = Colors.blueGrey, Color? iconColor = Colors.white, SvgGenImage? selectedIcon})
const

Properties

activeColor Color?
final
borderColor Color?
final
disabledColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
iconColor Color?
final
padding EdgeInsets?
final
radius double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedIcon → SvgGenImage?
final
size double?
final
type Object
The extension's type.
no setterinherited

Methods

copyWith() ThemeExtension<UICheckBoxThemeData>
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<UICheckBoxThemeData>? other, double t) ThemeExtension<UICheckBoxThemeData>
Linearly interpolate with another ThemeExtension object.
override
merge(covariant UICheckBoxThemeData? other) UICheckBoxThemeData
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited