UICheckerThemeData class
- Inheritance
-
- Object
- ThemeExtension<
UICheckerThemeData> - UICheckerThemeData
- Implemented types
Constructors
- UICheckerThemeData({double? size, EdgeInsets? padding, Color? activeColor, Color? disabledColor, Color? backgroundColor})
-
const
- UICheckerThemeData.config({double? size = 48, EdgeInsets? padding = const EdgeInsets.all(2), Color? activeColor = Colors.blue, Color? disabledColor = Colors.white70, Color? backgroundColor = Colors.blueGrey})
-
const
Properties
- activeColor → Color?
-
final
- backgroundColor → Color?
-
final
- disabledColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- padding → EdgeInsets?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → double?
-
final
- type → Object
-
The extension's type.
no setterinherited
Methods
-
copyWith(
) → ThemeExtension< UICheckerThemeData> -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ThemeExtension< UICheckerThemeData> ? other, double t) → ThemeExtension<UICheckerThemeData> -
Linearly interpolate with another ThemeExtension object.
override
-
merge(
covariant UICheckerThemeData? other) → UICheckerThemeData -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited