copyWith method
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
Implementation
@override
ThemeExtension<UIIconThemeData> copyWith() => this;
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
@override
ThemeExtension<UIIconThemeData> copyWith() => this;