UIKeyValueThemeData class
- Inheritance
-
- Object
- ThemeExtension<
UIKeyValueThemeData> - UIKeyValueThemeData
- Implemented types
Constructors
- UIKeyValueThemeData({double? fullSpacing, double? compactSpacing, TextStyle? compactTitleStyle, TextStyle? compactTextStyle, TextStyle? fullTitleStyle, TextStyle? fullTextStyle})
-
const
- UIKeyValueThemeData.config({double? fullSpacing = 4, double? compactSpacing = 4, TextStyle? compactTitleStyle = const TextStyle(fontSize: 14), TextStyle? compactTextStyle = const TextStyle(fontSize: 16), TextStyle? fullTitleStyle = const TextStyle(fontSize: 12), TextStyle? fullTextStyle = const TextStyle(fontSize: 12)})
-
const
Properties
- compactSpacing → double?
-
final
- compactTextStyle → TextStyle?
-
final
- compactTitleStyle → TextStyle?
-
final
- fullSpacing → double?
-
final
- fullTextStyle → TextStyle?
-
final
- fullTitleStyle → TextStyle?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → Object
-
The extension's type.
no setterinherited
Methods
-
copyWith(
) → ThemeExtension< UIKeyValueThemeData> -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ThemeExtension< UIKeyValueThemeData> ? other, double t) → ThemeExtension<UIKeyValueThemeData> -
Linearly interpolate with another ThemeExtension object.
override
-
merge(
covariant UIKeyValueThemeData? other) → UIKeyValueThemeData -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited