UILoadingThemeData class

Inheritance
Implemented types

Constructors

UILoadingThemeData({double? size, double? strokeWidth, Color? backgroundColor, Color? foregroundColor, Color? primary})
const
UILoadingThemeData.config({double? size = 24, double? strokeWidth = 4, Color? backgroundColor = Colors.grey, Color? foregroundColor = Colors.white70, Color? primary = Colors.blue})
const

Properties

backgroundColor Color?
final
foregroundColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
primary Color?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double?
final
strokeWidth double?
final
type Object
The extension's type.
no setterinherited

Methods

copyWith() ThemeExtension<UILoadingThemeData>
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<UILoadingThemeData>? other, double t) ThemeExtension<UILoadingThemeData>
Linearly interpolate with another ThemeExtension object.
override
merge(covariant UILoadingThemeData? other) UILoadingThemeData
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited