UISliversThemeData class

Inheritance
Implemented types

Constructors

UISliversThemeData({double? scrollPadding})
const
UISliversThemeData.config({double? scrollPadding = 12})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollPadding double?
final
type Object
The extension's type.
no setterinherited

Methods

copyWith() ThemeExtension<UISliversThemeData>
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<UISliversThemeData>? other, double t) ThemeExtension<UISliversThemeData>
Linearly interpolate with another ThemeExtension object.
override
merge(covariant UISliversThemeData? other) UISliversThemeData
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited