UISnackbarThemeData class
- Inheritance
-
- Object
- ThemeExtension<
UISnackbarThemeData> - UISnackbarThemeData
- Implemented types
Constructors
- UISnackbarThemeData({Color? backgroundColor, EdgeInsets? padding, EdgeInsets? margin, BorderRadius? borderRadius, double? spacing, double? runSpacing, double? textSpacing, BoxShadow? boxShadow})
-
const
- UISnackbarThemeData.config({Color? backgroundColor = Colors.white, EdgeInsets? padding = const EdgeInsets.symmetric(horizontal: 12, vertical: 16), EdgeInsets? margin = const EdgeInsets.symmetric(horizontal: 16, vertical: 16), BorderRadius? borderRadius = .zero, double? spacing = 8, double? runSpacing = 16, double? textSpacing = 4, BoxShadow? boxShadow = const BoxShadow(color: Colors.black26, blurRadius: 15)})
-
const
Properties
- backgroundColor → Color?
-
final
- borderRadius → BorderRadius?
-
final
- boxShadow → BoxShadow?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- margin → EdgeInsets?
-
final
- padding → EdgeInsets?
-
final
- runSpacing → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacing → double?
-
final
- textSpacing → double?
-
final
- type → Object
-
The extension's type.
no setterinherited
Methods
-
copyWith(
) → ThemeExtension< UISnackbarThemeData> -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ThemeExtension< UISnackbarThemeData> ? other, double t) → ThemeExtension<UISnackbarThemeData> -
Linearly interpolate with another ThemeExtension object.
override
-
merge(
covariant UISnackbarThemeData? other) → UISnackbarThemeData -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited