UISwitcherThemeData class

Inheritance
Implemented types

Constructors

UISwitcherThemeData({double? width, double? height, double? handSize, EdgeInsets? padding, Color? activeColor, Color? disabledColor, Color? foregroundColor, Color? backgroundColor})
const
UISwitcherThemeData.config({double? width = 48, double? height = 24, double? handSize = 20, EdgeInsets? padding = const EdgeInsets.all(3), Color? activeColor = Colors.blue, Color? disabledColor = Colors.grey, Color? foregroundColor = Colors.white, Color? backgroundColor = Colors.blueGrey})
const

Properties

activeColor Color?
final
backgroundColor Color?
final
disabledColor Color?
final
foregroundColor Color?
final
handSize double?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
padding EdgeInsets?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type Object
The extension's type.
no setterinherited
width double?
final

Methods

copyWith() ThemeExtension<UISwitcherThemeData>
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<UISwitcherThemeData>? other, double t) ThemeExtension<UISwitcherThemeData>
Linearly interpolate with another ThemeExtension object.
override
merge(covariant UISwitcherThemeData? other) UISwitcherThemeData
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited