UITabBarThemeData class
- Inheritance
-
- Object
- ThemeExtension<
UITabBarThemeData> - UITabBarThemeData
- Implemented types
Constructors
- UITabBarThemeData({Color? dividerColor, Color? selectedColor, Color? unSelectedColor, Color? shadowColor, TextStyle? textStyle, EdgeInsets? tabMargin, EdgeInsets? contentMargin, EdgeInsets? tabsPadding, double? separated})
-
const
- UITabBarThemeData.config({Color? dividerColor = Colors.black26, Color? selectedColor = Colors.blue, Color? unSelectedColor = Colors.black45, Color? shadowColor = Colors.white, TextStyle? textStyle = const TextStyle(fontSize: 16), EdgeInsets? tabMargin = const .symmetric(horizontal: 16), EdgeInsets? contentMargin = const .only(top: 48), EdgeInsets? tabsPadding = .zero, double? separated = 20})
-
const
Properties
- contentMargin → EdgeInsets?
-
final
- dividerColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedColor → Color?
-
final
- separated → double?
-
final
- shadowColor → Color?
-
final
- tabMargin → EdgeInsets?
-
final
- tabsPadding → EdgeInsets?
-
final
- textStyle → TextStyle?
-
final
- type → Object
-
The extension's type.
no setterinherited
- unSelectedColor → Color?
-
final
Methods
-
copyWith(
) → ThemeExtension< UITabBarThemeData> -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ThemeExtension< UITabBarThemeData> ? other, double t) → ThemeExtension<UITabBarThemeData> -
Linearly interpolate with another ThemeExtension object.
override
-
merge(
covariant UITabBarThemeData? other) → UITabBarThemeData -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited