UITextExpandedThemeData class

Inheritance
Implemented types

Constructors

UITextExpandedThemeData({UIButtonThemeData? buttonTheme, double? spacing})
const
UITextExpandedThemeData.config({UIButtonThemeData? buttonTheme = const UIButtonThemeData.config(height: 20), double? spacing = 4})
const

Properties

buttonTheme UIButtonThemeData?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double?
final
type Object
The extension's type.
no setterinherited

Methods

copyWith() ThemeExtension<UITextExpandedThemeData>
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<UITextExpandedThemeData>? other, double t) ThemeExtension<UITextExpandedThemeData>
Linearly interpolate with another ThemeExtension object.
override
merge(covariant UITextExpandedThemeData? other) UITextExpandedThemeData
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited