UITextHtmlThemeData class

Inheritance
Implemented types

Constructors

UITextHtmlThemeData({TextStyle? pStyle, TextStyle? strongStyle})
const
UITextHtmlThemeData.config({TextStyle? pStyle = const TextStyle(fontSize: 14, fontWeight: FontWeight.w400), TextStyle? strongStyle = const TextStyle(fontSize: 14, fontWeight: FontWeight.bold)})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
pStyle TextStyle?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strongStyle TextStyle?
final
type Object
The extension's type.
no setterinherited

Methods

copyWith() ThemeExtension<UITextHtmlThemeData>
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<UITextHtmlThemeData>? other, double t) ThemeExtension<UITextHtmlThemeData>
Linearly interpolate with another ThemeExtension object.
override
merge(covariant UITextHtmlThemeData? other) UITextHtmlThemeData
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited