UITextRequiredThemeData class

Inheritance
Implemented types

Constructors

UITextRequiredThemeData({Color? requiredColor, TextStyle? textStyle})
const
UITextRequiredThemeData.config({Color? requiredColor = Colors.red, TextStyle? textStyle = const TextStyle(fontSize: 16)})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
requiredColor Color?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle TextStyle?
final
type Object
The extension's type.
no setterinherited

Methods

copyWith() ThemeExtension<UITextRequiredThemeData>
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<UITextRequiredThemeData>? other, double t) ThemeExtension<UITextRequiredThemeData>
Linearly interpolate with another ThemeExtension object.
override
merge(covariant UITextRequiredThemeData? other) UITextRequiredThemeData
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited