DottedBorder class
A widget that draws a dotted border around its child.
The child is painted on top of or under the border, depending on childOnTop. Customization of the border is achieved by specifying the desired options.
An animation can be used to animate the dotted border. A repeated animation from 0 to 1 gives the effect of a continuously rotating border.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- DottedBorder
- Available extensions
Constructors
-
DottedBorder({Key? key, required Widget child, DottedBorderOptions options = const RectDottedBorderOptions(), bool ignoring = true, Animation<
double> ? animation, bool childOnTop = true}) -
const
Properties
-
animation
→ Animation<
double> ? -
The animation for the dotted border.
final
- child → Widget
-
The widget below this widget in the tree.
final
- childOnTop → bool
-
Wether to paint the child on top of the border.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ignoring → bool
-
Whether the border should ignore pointer events.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- options → DottedBorderOptions
-
The dotted border options.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
animate(
{Key? key, List< Effect> ? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, AnimationController? controller, Adapter? adapter, double? target, double? value}) → Animate -
Available on Widget, provided by the AnimateWidgetExtensions extension
Wraps the target Widget in an Animate instance, and returns the instance for chaining calls. Ex.myWidget.animate()is equivalent toAnimate(child: myWidget). -
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited