ScrollUtils class abstract

Constructors

ScrollUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

toScrollContext(BuildContext context, {double alignment = 0.5, Duration duration = Durations.long4}) Future<void>
toScrollKey(GlobalKey<State<StatefulWidget>> key, {double alignment = 0.5, Duration duration = Durations.long4}) Future<void>