Реализация интерфейса для метода merge
- Implemented types
- Implementers
- UIAgreementThemeData
- UIBadgeThemeData
- UIButtonThemeData
- UICheckBoxThemeData
- UICheckerThemeData
- UIDropdownThemeData
- UIFilterOptionsThemeData
- UIIconThemeData
- UIKeyValueThemeData
- UILoadingThemeData
- UISliversThemeData
- UISnackbarThemeData
- UISwitcherThemeData
- UITabBarThemeData
- UITagThemeData
- UITextExpandedThemeData
- UITextFieldThemeData
- UITextHtmlThemeData
- UITextRequiredThemeData
Properties
Methods
-
copyWith(
) → ThemeExtension< T> -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
inherited
-
lerp(
covariant ThemeExtension< T> ? other, double t) → ThemeExtension<T> -
Linearly interpolate with another ThemeExtension object.
inherited
-
merge(
covariant T? other) → T -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited