UIAgreementThemeData class
- Inheritance
-
- Object
- ThemeExtension<
UIAgreementThemeData> - UIAgreementThemeData
- Implemented types
Constructors
- UIAgreementThemeData({TextStyle? textStyle, TextStyle? linkStyle, double? spacing})
-
const
- UIAgreementThemeData.config({TextStyle? textStyle = const TextStyle(fontSize: 12, color: Colors.blue), TextStyle? linkStyle = const TextStyle(fontSize: 12), double? spacing = 8})
-
const
Properties
Methods
-
copyWith(
) → ThemeExtension< UIAgreementThemeData> -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ThemeExtension< UIAgreementThemeData> ? other, double t) → ThemeExtension<UIAgreementThemeData> -
Linearly interpolate with another ThemeExtension object.
override
-
merge(
covariant UIAgreementThemeData? other) → UIAgreementThemeData -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited