UIButtonThemeData class
- Inheritance
-
- Object
- ThemeExtension<
UIButtonThemeData> - UIButtonThemeData
- Implemented types
Constructors
- UIButtonThemeData({double? height, double? spacing, Color? backgroundColor, Color? foregroundColor, TextStyle? textStyle, BorderRadius? borderRadius, EdgeInsets? padding, UIIconThemeData? leftSuffixIcon, UIIconThemeData? rightSuffixIcon, BoxBorder? border, String? fontFamily})
-
const
- UIButtonThemeData.config({double? height = 48, double? spacing = 8, String? fontFamily = '', Color? backgroundColor = Colors.blue, Color? foregroundColor = Colors.white, TextStyle? textStyle = const TextStyle(fontSize: 16), BorderRadius? borderRadius = const BorderRadius.all(Radius.circular(20)), EdgeInsets? padding = const EdgeInsets.symmetric(horizontal: 10), UIIconThemeData? leftSuffixIcon = const UIIconThemeData.icon(iconSize: 20), UIIconThemeData? rightSuffixIcon = const UIIconThemeData.icon(iconSize: 20), BoxBorder? border = const Border.fromBorderSide(BorderSide(color: Colors.black38, width: 1, style: .solid, strokeAlign: BorderSide.strokeAlignInside))})
-
const
Properties
- backgroundColor → Color?
-
final
- border → BoxBorder?
-
final
- borderRadius → BorderRadius?
-
final
- fontFamily → String?
-
final
- foregroundColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- leftSuffixIcon → UIIconThemeData?
-
final
- padding → EdgeInsets?
-
final
- rightSuffixIcon → UIIconThemeData?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacing → double?
-
final
- textStyle → TextStyle?
-
final
- type → Object
-
The extension's type.
no setterinherited
Methods
-
copyWith(
) → ThemeExtension< UIButtonThemeData> -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ThemeExtension< UIButtonThemeData> ? other, double t) → ThemeExtension<UIButtonThemeData> -
Linearly interpolate with another ThemeExtension object.
override
-
merge(
covariant UIButtonThemeData? other) → UIButtonThemeData -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited