UIDropdownThemeData class

Inheritance
Implemented types

Constructors

UIDropdownThemeData({double? height, double? iconSize, Color? overlayBackgroundColor, Color? iconColor, Color? buttonBackgroundColor, Color? shadowColor, TextStyle? textStyle, TextStyle? hintStyle, BorderRadius? buttonBorderRadius, BorderRadius? overlayBorderRadius, EdgeInsets? itemPadding, EdgeInsets? iconPadding, EdgeInsets? buttonPadding, Border? border})
const
UIDropdownThemeData.config({double? height = 48, double? iconSize = 16, Color? overlayBackgroundColor = Colors.white, Color? iconColor = Colors.black, Color? buttonBackgroundColor = Colors.black12, Color? shadowColor = Colors.black12, TextStyle? textStyle = const TextStyle(fontSize: 12), TextStyle? hintStyle = const TextStyle(fontSize: 12), BorderRadius? buttonBorderRadius = const BorderRadius.all(Radius.circular(100)), BorderRadius? overlayBorderRadius = const BorderRadius.all(Radius.circular(20)), Border? border = const Border.fromBorderSide(BorderSide(color: Colors.black26, width: 1)), EdgeInsets? itemPadding = const EdgeInsets.symmetric(horizontal: 12), EdgeInsets? iconPadding = const EdgeInsets.only(left: 8), EdgeInsets? buttonPadding = const EdgeInsets.symmetric(horizontal: 12)})
const

Properties

border Border?
final
buttonBackgroundColor Color?
final
buttonBorderRadius BorderRadius?
final
buttonPadding EdgeInsets?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
hintStyle TextStyle?
final
iconColor Color?
final
iconPadding EdgeInsets?
final
iconSize double?
final
itemPadding EdgeInsets?
final
overlayBackgroundColor Color?
final
overlayBorderRadius BorderRadius?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadowColor Color?
final
textStyle TextStyle?
final
type Object
The extension's type.
no setterinherited

Methods

copyWith() ThemeExtension<UIDropdownThemeData>
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<UIDropdownThemeData>? other, double t) ThemeExtension<UIDropdownThemeData>
Linearly interpolate with another ThemeExtension object.
override
merge(covariant UIDropdownThemeData? other) UIDropdownThemeData
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited