UIIconThemeData class
- Inheritance
-
- Object
- ThemeExtension<
UIIconThemeData> - UIIconThemeData
- Implemented types
Constructors
- UIIconThemeData({Color? backgroundColor, Color? foregroundColor, double? containerSize, double? iconSize, BorderRadius? borderRadius, BoxShadow? boxShadow})
-
const
- UIIconThemeData.config({Color? backgroundColor = Colors.transparent, Color? foregroundColor = Colors.black, double? containerSize = 24, double? iconSize = 0, BorderRadius? borderRadius = .zero, BoxShadow? boxShadow})
-
const
- UIIconThemeData.icon({Color? foregroundColor = Colors.black, double? iconSize = 0})
-
const
Properties
- backgroundColor → Color?
-
final
- borderRadius → BorderRadius?
-
final
- boxShadow → BoxShadow?
-
final
- containerSize → double?
-
final
- foregroundColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconSize → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → Object
-
The extension's type.
no setterinherited
Methods
-
copyWith(
) → ThemeExtension< UIIconThemeData> -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ThemeExtension< UIIconThemeData> ? other, double t) → ThemeExtension<UIIconThemeData> -
Linearly interpolate with another ThemeExtension object.
override
-
merge(
covariant UIIconThemeData? other) → UIIconThemeData -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited