UITextFieldThemeData class
- Inheritance
-
- Object
- ThemeExtension<
UITextFieldThemeData> - UITextFieldThemeData
- Implemented types
Constructors
- UITextFieldThemeData({double? borderWidth, double? height, BoxConstraints? iconConstraints, double? titleSpacing, Color? focusBorderColor, Color? borderColor, Color? errorColor, Color? backgroundColor, Color? cursorColor, TextStyle? counterStyle, TextStyle? titleStyle, TextStyle? textStyle, TextStyle? hintStyle, TextStyle? labelStyle, TextStyle? errorStyle, BorderRadius? defaultBorderRadius, BorderRadius? moreLinesBorderRadius, EdgeInsets? contentPadding, UIIconThemeData? cleanSuffixIcon, UIIconThemeData? obscureSuffixIcon})
-
const
- UITextFieldThemeData.config({double? borderWidth = 1, double? height, BoxConstraints? iconConstraints = const BoxConstraints.tightFor(width: 40, height: 20), double? titleSpacing = 4, Color? focusBorderColor = Colors.black45, Color? borderColor = Colors.black26, Color? errorColor = Colors.red, Color? backgroundColor = Colors.black12, Color? cursorColor = Colors.black, TextStyle? counterStyle = const TextStyle(fontSize: 12), TextStyle? titleStyle = const TextStyle(fontSize: 14), TextStyle? textStyle = const TextStyle(fontSize: 16), TextStyle? hintStyle = const TextStyle(fontSize: 12), TextStyle? labelStyle = const TextStyle(fontSize: 12), TextStyle? errorStyle = const TextStyle(fontSize: 12), BorderRadius? defaultBorderRadius = BorderRadius.zero, BorderRadius? moreLinesBorderRadius = BorderRadius.zero, EdgeInsets? contentPadding = const EdgeInsets.only(top: 12, bottom: 12, left: 8, right: -4), UIIconThemeData? cleanSuffixIcon = const UIIconThemeData(iconSize: 7.5, containerSize: 16), UIIconThemeData? obscureSuffixIcon = const UIIconThemeData.icon(iconSize: 20)})
-
const
Properties
- backgroundColor → Color?
-
final
- borderColor → Color?
-
final
- borderWidth → double?
-
final
- cleanSuffixIcon → UIIconThemeData?
-
final
- contentPadding → EdgeInsets?
-
final
- counterStyle → TextStyle?
-
final
- cursorColor → Color?
-
final
- defaultBorderRadius → BorderRadius?
-
final
- errorColor → Color?
-
final
- errorStyle → TextStyle?
-
final
- focusBorderColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- hintStyle → TextStyle?
-
final
- iconConstraints → BoxConstraints?
-
final
- labelStyle → TextStyle?
-
final
- moreLinesBorderRadius → BorderRadius?
-
final
- obscureSuffixIcon → UIIconThemeData?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textStyle → TextStyle?
-
final
- titleSpacing → double?
-
final
- titleStyle → TextStyle?
-
final
- type → Object
-
The extension's type.
no setterinherited
Methods
-
copyWith(
) → ThemeExtension< UITextFieldThemeData> -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ThemeExtension< UITextFieldThemeData> ? other, double t) → ThemeExtension<UITextFieldThemeData> -
Linearly interpolate with another ThemeExtension object.
override
-
merge(
covariant UITextFieldThemeData? other) → UITextFieldThemeData -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited